# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to tweak the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# Pick up the right dictionary for the spell check
%if %(perl -e 'print $] >= 5.010000 ? 1 : 0;')
%global speller hunspell
%else
%global speller aspell
%endif

# Perl and RPM versioning don't work the same :-(
%global extraversion 02

Name:		perl-Test-Unit-Lite
Epoch:		1
Version:	0.12
Release:	14.%{__distinit}%{__distvers}
Summary:	Unit testing without external dependencies
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Test-Unit-Lite/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DE/DEXTER/Test-Unit-Lite-%{version}%{?extraversion}.tar.gz
Source1:	C0B10A5B.pub
Patch0:		Test-Unit-Lite-0.1202-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Module::Build)
BuildRequires:	perl(Taint::Runtime)
# Release test requirements
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
# Test::CPAN::Changes only available if we have Perl 5.10.0 onwards
%if %(perl -e 'print $] >= 5.010000 ? 1 : 0;')
BuildRequires:	perl(Test::CPAN::Changes)
%endif
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::DistManifest)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling), %{speller}-en
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Filter unwanted provides and requires (rpm 4.9 onwards)
%global __provides_exclude ^perl\\(Test::Unit::(Debug|HarnessUnit|Result|TestCase|TestRunner|TestSuite)\\)$
%global __requires_exclude ^perl\\(Test::Unit::Test(Runner|Suite)\\)

%description
This framework provides a lighter version of Test::Unit framework. It
implements some of the Test::Unit classes and methods needed to run test
units. Test::Unit::Lite tries to be compatible with public API of
Test::Unit. It doesn't implement all classes and methods at 100% and only
those necessary to run tests are available.

%prep
%setup -q -c -n Test-Unit-Lite

# Copy up documentation for convenience with %%doc
cp -a Test-Unit-Lite-%{version}%{?extraversion}/{Changes,LICENSE,README} .

# Create a GPG directory for testing, to avoid using ~/.gnupg
mkdir --mode=0700 gnupghome
GNUPGHOME=$(pwd)/gnupghome gpg --import %{SOURCE1}

# We need to tweak the test suite if we have an old version of Test::More
%if %{old_test_more}
%patch0 -p1
%endif

# Filter unwanted provides and (prior to rpm 4.9)
# Unwanted requires not actually detected prior to rpm 4.9
%global provfilt /bin/sh -c "%{__perl_provides} | grep -Evx 'perl\\(Test::Unit::(Debug|HarnessUnit|Result|TestCase|TestRunner|TestSuite)\\)'"
%define __perl_provides %{provfilt}

%build
cd Test-Unit-Lite-%{version}%{?extraversion}
perl Build.PL installdirs=vendor
./Build
cd -

%install
rm -rf %{buildroot}
cd Test-Unit-Lite-%{version}%{?extraversion}
./Build install destdir=%{buildroot} create_packlist=0
cd -
%{_fixperms} %{buildroot}

%check
export GNUPGHOME=$(pwd)/gnupghome
cd Test-Unit-Lite-%{version}%{?extraversion}

# === MAIN TEST SUITE === #

./Build test

# ===  RELEASE TESTS  === #
RELEASE_TESTS="$(echo xt/*.t)"

# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"

# Test::CPAN::Changes only available if we have Perl 5.10.0 onwards
%if %(perl -e 'print $] >= 5.010000 ? 0 : 1;')
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/cpan_changes.t||')"
%endif

# Don't run the spelling test yet as we need to add extra stopwords
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/pod_spell.t||')"

# If we don't have Test::More ≥ 0.88, we need to patch the test suite so we
# can't run the signature test
%if %{old_test_more}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/signature.t||')"
%endif

# Signature test would fail on recent distros due to presence of MYMETA.*
[ -f MYMETA.yml ] && mv MYMETA.yml ..
[ -f MYMETA.json ] && mv MYMETA.json ..

./Build test --test_files "$RELEASE_TESTS"

# Put any MYMETA.* files back where they were
[ -f ../MYMETA.yml ] && mv ../MYMETA.yml .
[ -f ../MYMETA.json ] && mv ../MYMETA.json .

# Fix the POD Spell test and run it
mv xt/pod_spellrc xt/pod_spellrc.orig
(
	cat xt/pod_spellrc.orig
	echo "ARG1"
	echo "ARG2"
	echo "doesn"
) > xt/pod_spellrc
./Build test --test_files xt/pod_spell.t
mv xt/pod_spellrc.orig xt/pod_spellrc

cd -

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes LICENSE README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Unit::Lite.3pm*

%changelog
* Fri Dec 21 2012 Paul Howarth <paul@city-fan.org> - 1:0.12-14
- Update to 0.1202
  - Fix for hash key randomization after 5.17.5 (CPAN RT#81879)
- Run release tests and add lots of build dependencies for them

* Sat Jun 23 2012 Paul Howarth <paul@city-fan.org> - 1:0.12-13
- Perl 5.16 rebuild

* Sun Mar 25 2012 Paul Howarth <paul@city-fan.org> - 1:0.12-12
- Update to 0.1201
  - Repackaged with newer Module::Builder

* Sat Mar 24 2012 Paul Howarth <paul@city-fan.org> - 1:0.12-11
- Add buildreqs for Perl core modules that could be dual-lived
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Don't need to run test suite with LC_ALL=C

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 1:0.12-8
- Rebuild for perl 5.14.1 in Rawhide
- Filter dependencies on perl(Test::Unit::TestRunner) and
  perl(Test::Unit::TestSuite) as this package includes its own implementation
  of these and we'd otherwise pull in the full Test::Unit
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu May  5 2011 Paul Howarth <paul@city-fan.org> - 1:0.12-7
- Import from Fedora

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.12-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Marcela Maslanova <mmaslano@redhat.com> - 1:0.12-5
- Rebuild to fix problems with vendorarch/lib (#661697)

* Fri May 07 2010 Marcela Maslanova <mmaslano@redhat.com> - 1:0.12-4
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 1:0.12-3
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun 08 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1:0.12-1
- Auto-update to 0.12 (by cpan-spec-update 0.01)
- Add epoch of 1 (0.1101 => 0.12)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1101-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 12 2009 Allisson Azevedo <allisson@gmail.com> - 0.1101-2
- Added filter provides

* Thu Jan 29 2009 Allisson Azevedo <allisson@gmail.com> - 0.1101-1
- Initial rpm release
